@@ -10,7 +10,8 @@
 #' @return an object of class "SDMXCompactData"
 #' 
 #' @seealso \link{readSDMX}
-#'
+#' @export
+#' 
 SDMXCompactData <- function(xmlObj, namespaces){
   new("SDMXCompactData",
       SDMXData(xmlObj, namespaces)
@@ -18,7 +19,7 @@ SDMXCompactData <- function(xmlObj, namespaces){
 }
 
 #methods
-as.data.frame.SDMXAllCompactData <- function(x, nsExpr, labels = FALSE, ...) {
+getSDMXAllCompactData <- function(x, nsExpr, labels = FALSE, ...) {
   xmlObj <- x@xmlObj;
   dataset <- NULL
   
@@ -30,31 +31,45 @@ as.data.frame.SDMXAllCompactData <- function(x, nsExpr, labels = FALSE, ...) {
   hasAuthorityNS <- FALSE
   nsDefs.df <- getNamespaces(x)
   ns <- findNamespace(nsDefs.df, nsExpr)
+  if(length(ns) > 1) ns <- ns[1]
   
-  authorityNs <- nsDefs.df[
+  authorityNamespaces <- nsDefs.df[
     regexpr("http://www.sdmx.org", nsDefs.df$uri,
             "match.length", ignore.case = TRUE) == -1,]
-  authorityNs <- as.data.frame(authorityNs, stringsAsFactors = FALSE)
-  colnames(authorityNs) <- "uri"
+  authorityNamespaces <- as.data.frame(authorityNamespaces, stringsAsFactors = FALSE)
+  colnames(authorityNamespaces) <- "uri"
   
-  if(nrow(authorityNs) > 0){
+  if(nrow(authorityNamespaces) > 0){
+    nsIdx <- 1
     hasAuthorityNS <- TRUE
-    if(nrow(authorityNs) > 1){
-      warning("More than one target dataset namespace found!")
-      authorityNs <- authorityNs[1L,]
+    if(nrow(authorityNamespaces) > 1){
+      authorityNs <- authorityNamespaces[nsIdx,]
       authorityNs <- as.data.frame(authorityNs, stringsAsFactors = FALSE)
       colnames(authorityNs) <- "uri"
+    }else{
+      authorityNs <- authorityNamespaces
     }
   }
   
   if(hasAuthorityNS){
+    #try to get series with authority namespaces
     seriesXML <- getNodeSet(xmlObj, "//ns:Series", namespaces = c(ns = authorityNs$uri))
+    while(nsIdx <= nrow(authorityNamespaces) && length(seriesXML) == 0){
+      nsIdx <- nsIdx + 1
+      authorityNs <- authorityNamespaces[nsIdx,]
+      authorityNs <- as.data.frame(authorityNs, stringsAsFactors = FALSE)
+      colnames(authorityNs) <- "uri"
+      seriesXML <- getNodeSet(xmlObj, "//ns:Series", namespaces = c(ns = authorityNs$uri))
+    }
+    
     if(length(seriesXML) == 0){
-      seriesXML <- getNodeSet(xmlObj, "//ns:Series", namespaces = ns)
+      seriesXML <- try(getNodeSet(xmlObj, "//ns:Series", namespaces = ns), silent = TRUE)
+      if(is(seriesXML,"try-error")) seriesXML <- list()
     }
   }else{
     if(length(ns) > 0){
-      seriesXML <- getNodeSet(xmlObj, "//ns:Series", namespaces = ns)
+      seriesXML <- try(getNodeSet(xmlObj, "//ns:Series", namespaces = ns), silent = TRUE)
+      if(is(seriesXML,"try-error")) seriesXML <- list()
     }else{
       if(nrow(nsDefs.df) > 0){
         serieNs <- nsDefs.df[1,]
@@ -88,7 +103,7 @@ as.data.frame.SDMXAllCompactData <- function(x, nsExpr, labels = FALSE, ...) {
     
     #obs children (in case we have)
     obsValues <- try(xmlToDataFrame(obsValueXML, stringsAsFactors = FALSE), silent=TRUE)
-    if(class(obsValues) == "try-error"){
+    if(is(obsValues,"try-error")){
       obsValues <- NULL
     }else{
       obsKeyNames <- names(lapply(obsValueXML, xmlChildren)[["Key"]])
@@ -101,7 +116,7 @@ as.data.frame.SDMXAllCompactData <- function(x, nsExpr, labels = FALSE, ...) {
     keydf <- as.data.frame(t(as.data.frame(xmlAttrs(x), stringAsFactors = FALSE)), stringAsFactors = FALSE)
     if(nrow(obsAttrs) > 0){
       keydf <- keydf[rep(row.names(keydf), nrow(obsAttrs)),]
-      if(class(keydf) == "data.frame") row.names(keydf) <- 1:nrow(obsAttrs)
+      if(is(keydf,"data.frame")) row.names(keydf) <- 1:nrow(obsAttrs)
     }
     
     #single Serie as DataFrame
@@ -137,8 +152,8 @@ as.data.frame.SDMXAllCompactData <- function(x, nsExpr, labels = FALSE, ...) {
   return(encodeSDMXOutput(dataset))
 }
 
-
+#'@export
 as.data.frame.SDMXCompactData <- function(x, row.names=NULL, optional=FALSE,
                                           labels = FALSE, ...){
-  return(as.data.frame.SDMXAllCompactData(x, "compact", labels));
+  return(getSDMXAllCompactData(x, nsExpr = "compact", labels = labels));
 }
