@@ -10,7 +10,8 @@
 #' @return an object of class "SDMXMessageGroup"
 #' 
 #' @seealso \link{readSDMX}
-#'
+#' @export
+#' 
 SDMXMessageGroup <- function(xmlObj, namespaces){
   new("SDMXMessageGroup",
       SDMXData(xmlObj, namespaces)
@@ -47,7 +48,9 @@ class.SDMXMessageGroup <- function(xmlObj){
     seriesKeyXML <- getNodeSet(xmlObj, "//ns:SeriesKey", c(ns = authorityNs$uri)) 
   }else{
     if(nrow(nsDefs.df) > 0){
-      seriesKeyXML <- getNodeSet(xmlObj, "//ns:SeriesKey", c(ns = nsDefs.df[1,"uri"])) 
+      serieNs <- nsDefs.df[regexpr("generic$", nsDefs.df$uri)>0,"uri"]
+      if(length(serieNs)==0) serieNs <- nsDefs.df[1,"uri"]
+      seriesKeyXML <- getNodeSet(xmlObj, "//ns:SeriesKey", c(ns = serieNs))
     }else{    
       stop("Unsupported XML parser for empty target XML namespace")
     }
@@ -63,6 +66,7 @@ class.SDMXMessageGroup <- function(xmlObj){
   
 }
 
+#'@export
 as.data.frame.SDMXMessageGroup <- function(x, row.names=NULL, optional=FALSE,
                                            labels = FALSE, ...){
   #TODO support for other included message types
