@@ -31,8 +31,7 @@ test_that("Main helpers arguments",{
   expect_error(readSDMX(providerId = providerId2, resource = "dataflow"), "No provider with identifier IMF!")
   
   #wrong request
-  expect_error(readSDMX(providerId = "KNOEMA", resource = "data", flowRef = "SADG2015-WRONG"),
-               "HTTP request failed with status: 400 ")
+  expect_error(readSDMX(providerId = "OECD", resource = "data", flowRef = "SADG2015-WRONG"))
   
 })
 
@@ -118,7 +117,7 @@ test_that("ESTAT - dataflow",{
 #-> datastructure
 test_that("ESTAT - datastructure",{
   testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "ESTAT", resource = "datastructure", resourceId = "DSD_tec00118")
+  sdmx <- readSDMX(providerId = "ESTAT", resource = "datastructure", resourceId = "NAMA_10_GDP")
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXDataStructureDefinition")
   }
@@ -128,8 +127,7 @@ test_that("ESTAT - datastructure",{
 test_that("ESTAT - data",{
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ESTAT", resource = "data",
-                   flowRef = "tec00118", key = "all",
-                   start = 2020, end = 2020)
+                   flowRef = "NAMA_10_GDP", key = "A.CP_MEUR.B1GQ.BE+LU")
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXGenericData")
   }
@@ -181,7 +179,7 @@ test_that("OECD - dataflow",{
 #-> datastructure
 test_that("OECD - datastructure",{
   testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "OECD", resource = "datastructure", resourceId = "TABLE1")
+  sdmx <- readSDMX(providerId = "OECD", resource = "datastructure", resourceId = "DSD_PRICES")
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXDataStructureDefinition")
   }
@@ -190,10 +188,10 @@ test_that("OECD - datastructure",{
 #-> data
 test_that("OECD - data",{
   testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "OECD", resource = "data",
-                   flowRef = "MIG", key = list("TOT", NULL, NULL), start = 2011, end = 2011)
+  sdmx <- readSDMX(providerId = "OECD", resource = "data", flowRef = "DSD_PRICES@DF_PRICES_N_CP01",
+                   key = list("GRC", NULL, NULL, NULL, NULL, NULL, NULL, NULL), start = 2020, end = 2020)
   if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXMessageGroup")
+    expect_is(sdmx, "SDMXGenericData")
   }
 })
 
@@ -297,26 +295,27 @@ test_that("UNSD - data",{
 
 #ILO_Legacy (UN-ILO)
 #------------
+#gives Unauthorized 403 status codes now
 
-#-> datastructure
-test_that("ILO - datastructure",{
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "ILO_Legacy", resource = "datastructure", resourceId = "YI_ALB_EAP_TEAP_SEX_AGE_NB")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataStructureDefinition")
-  }
-})
-
-#-> data
-test_that("ILO - data",{
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "ILO_Legacy", resource = "data",
-                   flowRef = "DF_CPI_FRA_CPI_TCPI_COI_RT", key = "ALL", key.mode = "SDMX",
-                   start = "2010-01-01", end = "2014-12-31")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXGenericData")
-  }
-})
+# #-> datastructure
+# test_that("ILO - datastructure",{
+#   testthat::skip_on_cran()
+#   sdmx <- readSDMX(providerId = "ILO_Legacy", resource = "datastructure", resourceId = "YI_ALB_EAP_TEAP_SEX_AGE_NB")
+#   if(!is.null(sdmx)){
+#     expect_is(sdmx, "SDMXDataStructureDefinition")
+#   }
+# })
+# 
+# #-> data
+# test_that("ILO - data",{
+#   testthat::skip_on_cran()
+#   sdmx <- readSDMX(providerId = "ILO_Legacy", resource = "data",
+#                    flowRef = "DF_CPI_FRA_CPI_TCPI_COI_RT", key = "ALL", key.mode = "SDMX",
+#                    start = "2010-01-01", end = "2014-12-31")
+#   if(!is.null(sdmx)){
+#     expect_is(sdmx, "SDMXGenericData")
+#   }
+# })
 
 #ILO (UN-ILO)
 #------------
@@ -571,19 +570,19 @@ test_that("ISTAT - dataflow",{
 
 #-> datastructure
 #TODO investigate issue with xmlNamespaceDefinitions (XML)
-test_that("ISTAT - datastructure",{
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "ISTAT", resource = "datastructure", resourceId = "DCCV_CONSACQUA")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataStructureDefinition")
-  }
-})
+# test_that("ISTAT - datastructure",{
+#   testthat::skip_on_cran()
+#   sdmx <- readSDMX(providerId = "ISTAT", resource = "datastructure", resourceId = "DCCV_CONSACQUA")
+#   if(!is.null(sdmx)){
+#     expect_is(sdmx, "SDMXDataStructureDefinition")
+#   }
+# })
 
 #-> data
 test_that("ISTAT - data",{
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ISTAT", resource = "data",
-                   flowRef = "12_60", start = 2015, end = 2015)
+                   flowRef = "12_60_DF_DCCV_CONSACQUA_1", start = 2015, end = 2015)
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXGenericData")
   }
@@ -705,29 +704,6 @@ test_that("NCSI - datastructure",{
 #  }
 #})
 
-#STAT_E (Estonia)
-#-------------
-
-#-> datastructure
-test_that("STAT_EE - datastructure",{
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "STAT_EE", resource = "datastructure", resourceId = "KK11")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataStructureDefinition")
-  }
-})
-
-#-> data
-test_that("STAT_EE - data",{
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "STAT_EE", resource = "data",
-                   flowRef = "KK11", key = "all", key.mode = "SDMX",
-                   start = "2015", end = "2015")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXMessageGroup")
-  }
-})
-
 
 #BBK (Bundesbank)
 #-------------
